==> qtjambi-multimediawidgets-debuginfo-macos-6.5.4.jar: sources/QtJambiMultimediaWidgets/QGraphicsVideoItem_shell.h <==
#ifndef QGRAPHICSVIDEOITEM_SHELL_H
#define QGRAPHICSVIDEOITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimediaWidgets/qgraphicsvideoitem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <QtMultimedia/qvideosink.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QGraphicsVideoItem_shell : public QGraphicsVideoItem, public QtJambiShellInterface
{
public:
    QGraphicsVideoItem_shell(QGraphicsItem* parent0 = nullptr);
    ~QGraphicsVideoItem_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* ev0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    QPainterPath shape() const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsVideoItem_access : public QGraphicsVideoItem
{
    jobject __qt_boundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_itemChange_QGraphicsItem_GraphicsItemChange_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint change0, jobject value1);
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QGRAPHICSVIDEOITEM_SHELL_H

==> qtjambi-multimediawidgets-debuginfo-macos-6.5.6.jar: sources/QtJambiMultimediaWidgets/QGraphicsVideoItem_shell.h <==
#ifndef QGRAPHICSVIDEOITEM_SHELL_H
#define QGRAPHICSVIDEOITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimediaWidgets/qgraphicsvideoitem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtransform.h>
#include <QtMultimedia/qvideosink.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QGraphicsVideoItem_shell : public QGraphicsVideoItem, public QtJambiShellInterface
{
public:
    QGraphicsVideoItem_shell(QGraphicsItem* parent0 = nullptr);
    ~QGraphicsVideoItem_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* ev0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    QPainterPath shape() const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsVideoItem_access : public QGraphicsVideoItem
{
    jobject __qt_boundingRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_itemChange_QGraphicsItem_GraphicsItemChange_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint change0, jobject value1);
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // QGRAPHICSVIDEOITEM_SHELL_H
